@@ -5,6 +5,7 @@ package Array::Circular;
 
 use Carp;
 use Scalar::Util qw/refaddr/;
+use Storable qw/dclone/;
 
 my %DATA;
 
@@ -15,6 +16,15 @@ sub new {
     return $self;
 }
 
+sub clone {
+    my ($self) = @_;
+    my $class = ref $self;
+    my $new = $class->new(@$self);
+    $new->index($self->index);
+    $new->loops($self->loops);
+    return $new;
+}
+
 sub me {
     my ($self, $args) = @_;
     my $loc = refaddr $self;
@@ -158,6 +168,10 @@ Circular array, tracks how many times it's been round.
 
     my $a = Array::Circular->new(qw/this is a test/);
 
+=head3 clone
+
+    my $new = $a->clone;
+
 =head3 next
 
     my $element     = $l->next;
